Allows users to access the Oregon State Prism climate data (https://prism.nacse.org/). Using the web service API data can easily downloaded in bulk and loaded into R for spatial analysis. Some user friendly visualizations are also provided.
Maintainer: Alan Butler [email protected] (ORCID) [contributor]
Authors:
Hart Edmund [email protected] [conceptor]
Kendon Bell [email protected]
Useful links: